@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -6,12 +7,12 @@
 -- |
 --  Module      :  ClassRestrictionRule
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012 Douglas Burke
+--                 2011, 2012, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 --
 --  This module implements an inference rule based on a restruction on class
 --  membership of one or more values.
@@ -60,9 +61,12 @@ import Control.Monad (liftM)
 
 import Data.List (delete, nub, subsequences)
 import Data.Maybe (fromJust, fromMaybe, mapMaybe)
-import Data.Monoid (Monoid (..))
 import Data.Ord.Partial (minima, maxima, partCompareEq, partComparePair, partCompareListMaybe, partCompareListSubset)
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
+import Data.Monoid (Monoid (..))
+#endif
+
 import qualified Data.Map as M
 import qualified Data.Set as S
 import qualified Data.Text.Lazy.Builder as B
