@@ -9,7 +9,7 @@
 -- |
 --  Module      :  Graph
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013, 2014, 2015 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2015, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -1278,7 +1278,7 @@ data NSGraph lb = NSGraph
     , statements :: ArcSet lb         -- ^ the statements in the graph
     }
 
-instance (Label lb) => LDGraph NSGraph lb where
+instance LDGraph NSGraph lb where
     emptyGraph   = NSGraph emptyNamespaceMap M.empty S.empty
     getArcs      = statements 
     setArcs g as = g { statements=as }
@@ -1309,7 +1309,7 @@ traverseNSGraph f (NSGraph ns fml stmts) =
     NSGraph ns <$> traverseFormulaMap f fml <*> (traverseSet $ Traversable.traverse f) stmts
 
 traverseSet ::
-    (Applicative f, Ord a, Ord b)
+    (Applicative f, Ord b)
     => (a -> f b) -> S.Set a -> f (S.Set b)
 traverseSet f = S.foldr cons (pure S.empty)
     where
