@@ -5,7 +5,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  N3
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -483,7 +483,7 @@ startChar c = let i = ord c
   
 inBody :: Char -> Bool
 inBody c = let i = ord c
-           in c `elem` "-_" || i == 0x007 ||
+           in c `elem` ("-_"::String) || i == 0x007 ||
               match c [('0', '9'), ('A', 'Z'), ('a', 'z')] ||
               match i [(0x00c0, 0x00d6), (0x00d8, 0x00f6), (0x00f8, 0x037d), 
                        (0x037f, 0x1fff), (0x200c, 0x200d), (0x203f, 0x2040), 
@@ -1103,7 +1103,9 @@ n3decimal :: N3Parser String
 n3decimal = (++) <$> n3integer <*> ( (:) <$> char '.' <*> many digit )
            
 n3double :: N3Parser String
-n3double = (++) <$> n3decimal <*> ( (:) <$> satisfy (`elem` "eE") <*> n3integer )
+n3double = (++) 
+           <$> n3decimal 
+           <*> ( (:) <$> satisfy (`elem` ("eE"::String)) <*> n3integer )
 
 -- Convert a double, as returned by n3double, into it's
 -- canonical XSD form. We assume that n3double returns
