@@ -5,7 +5,7 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Turtle
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
 --  License     :  GPL V2
 -- 
 --  Maintainer  :  Douglas Burke
@@ -641,7 +641,7 @@ isIRIChar :: Char -> Bool
 isIRIChar c =
   c > chr 0x20
   && 
-  c `notElem` "<>\"{}|^`\\"
+  c `notElem` ("<>\"{}|^`\\"::String)
 
 {-
 [139s]	PNAME_NS	::=	PN_PREFIX? ':'
@@ -777,7 +777,7 @@ _langTag = do
 -- Returns True for + and False for -.
 _leadingSign :: TurtleParser (Maybe Bool)
 _leadingSign = do
-  ms <- optional (satisfy (`elem` "+-"))
+  ms <- optional (satisfy (`elem` ("+-"::String)))
   return $ (=='+') `fmap` ms
 
 {-
