@@ -7,7 +7,8 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Proof
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
+--                 2011, 2012, 2014, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -72,7 +73,7 @@ import qualified Data.Set as S
 --  The empty RDF graph is always @True@ (other enduring
 --  truths are asserted as axioms).
 
-instance (Label lb, LDGraph lg lb, Eq (lg lb)) => Expression (lg lb) where
+instance (LDGraph lg lb, Eq (lg lb)) => Expression (lg lb) where
     isValid = S.null . getArcs 
 
 ------------------------------------------------------------
