@@ -6,7 +6,8 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  Ruleset
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
+--                 2011, 2012, 2014, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -145,7 +146,7 @@ instance (Label lb) => Eq (GraphClosure lb) where
                ruleAnt c1 == ruleAnt c2 &&
                ruleCon c1 == ruleCon c2
 
-instance (Label lb) => Show (GraphClosure lb) where
+instance Show (GraphClosure lb) where
     show c = "GraphClosure " ++ show (nameGraphRule c)
 
 ------------------------------------------------------------
