@@ -1,15 +1,17 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
+
 --------------------------------------------------------------------------------
 --  See end of this file for licence information.
 --------------------------------------------------------------------------------
 {- |
 Module      :  Script
-Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
 License     :  GPL V2
 
 Maintainer  :  Douglas Burke
 Stability   :  experimental
-Portability :  OverloadedStrings
+Portability :  CPP, OverloadedStrings
 
 This module implements the Swish script processor:  it parses a script
 from a supplied string, and returns a list of Swish state transformer
@@ -126,7 +128,9 @@ import Text.ParserCombinators.Poly.StateText
 import Control.Monad (unless, when, liftM, void)
 import Control.Monad.State (modify, gets, lift)
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Data.Monoid (Monoid(..))
+#endif
 
 import Network.URI (URI(..))
 
