@@ -9,7 +9,7 @@
 -- |
 --  Module      :  VarBinding
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 
---                 2011, 2012, 2014, 2015 Douglas Burke
+--                 2011, 2012, 2014, 2015, 2016 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -115,7 +115,7 @@ nullVarBinding = VarBinding
 -- |Return a list of the variables bound by a supplied variable binding
 --
 boundVars :: (Ord a, Ord b) => VarBinding a b -> S.Set a
-boundVars = S.map fst . vbEnum
+boundVars = S.map fst . vbEnum  -- Ord b is needed got GHC 7.6
 
 -- |VarBinding subset function, tests to see if one query binding
 --  is a subset of another;  i.e. every query variable mapping defined
