@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE OverloadedStrings #-}
 
 --------------------------------------------------------------------------------
@@ -5,12 +6,12 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  RDFGraphTest
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2013, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  OverloadedStrings
+--  Portability :  CPP, OverloadedStrings
 --
 --  This module contains test cases for module RDFGraph.
 --
@@ -65,13 +66,20 @@ import Control.Arrow ((&&&), first)
 
 import Data.List (elemIndex, intercalate)
 import Data.Maybe (fromJust, fromMaybe)
-import Data.Monoid (Monoid(..))
 import Data.Ord (comparing)
-import Data.Time (UTCTime(..), Day, fromGregorian, buildTime)
+
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
+import Data.Monoid (Monoid(..))
+#endif
 
 import Network.URI (URI, parseURI)
 
+#if MIN_VERSION_time(1,5,0)
+import Data.Time (UTCTime(..), Day, fromGregorian, buildTime, defaultTimeLocale)
+#else
+import Data.Time (UTCTime(..), Day, fromGregorian, buildTime)
 import System.Locale (defaultTimeLocale)
+#endif
 
 import Test.HUnit
     ( Test(TestCase,TestList,TestLabel)
@@ -126,12 +134,14 @@ langeqlist =
 testLangEq :: String -> Bool -> Lang -> Lang -> Test
 testLangEq = testCompareEq "testLangEq:"
 
+hyphen :: String -> String -> String
+hyphen a b = a ++ "-" ++ b
+
 testLangEqSuite :: Test
 testLangEqSuite = TestList
-  [ testLangEq (tLab ll1 ll2) (tEq  ll1 ll2) t1 t2
+  [ testLangEq (ll1 `hyphen` ll2) (tEq  ll1 ll2) t1 t2
       | (ll1,t1) <- langlist , (ll2,t2) <- langlist ]
     where
-    tLab ll1 ll2 = ll1 ++ "-" ++ ll2
     tEq  ll1 ll2 = (ll1 == ll2)        ||
          (ll1,ll2) `elem` langeqlist ||
          (ll2,ll1) `elem` langeqlist
@@ -329,10 +339,9 @@ nodeeqlist =
 
 testNodeEqSuite :: Test
 testNodeEqSuite = TestList
-  [ testLabelEq (tLab ll1 ll2) (tEq  ll1 ll2) n1 n2
+  [ testLabelEq (ll1 `hyphen` ll2) (tEq  ll1 ll2) n1 n2
       | (ll1,n1) <- nodelist , (ll2,n2) <- nodelist ]
     where
-    tLab ll1 ll2 = ll1 ++ "-" ++ ll2
     tEq  ll1 ll2 = (ll1 == ll2)        ||
          (ll1,ll2) `elem` nodeeqlist ||
          (ll2,ll1) `elem` nodeeqlist
@@ -726,10 +735,9 @@ nodeorder =
 
 testNodeOrdSuite :: Test
 testNodeOrdSuite = TestList
-  [ testLabelOrd (tLab ll1 ll2) (tOrd ll1 ll2) n1 n2
+  [ testLabelOrd (ll1 `hyphen` ll2) (tOrd ll1 ll2) n1 n2
       | (ll1,n1) <- nodelist , (ll2,n2) <- nodelist ]
     where
-    tLab ll1 ll2 = ll1 ++ "-" ++ ll2
     tOrd ll1 ll2
       | tEq ll1 ll2  = EQ
       | otherwise    = comparing fromJust 
@@ -778,7 +786,7 @@ tlist :: [(String, RDFTriple)]
 tlist =
   [ (lab s p o,trp s p o) | s <- slist, p <- plist, o <- olist ]
     where
-    lab (s,_) (p,_) (o,_) = intercalate "." [s, p, o]
+    lab (s,_) (p,_) (o,_) = intercalate ("."::String) [s, p, o]
     trp (_,s) (_,p) (_,o) = arc s p o
 
 stmteqlist :: [(String, String)]
@@ -803,10 +811,9 @@ stmteqlist =
 
 testStmtEqSuite :: Test
 testStmtEqSuite = TestList
-  [ testStmtEq (tLab ll1 ll2) (tEq  ll1 ll2) t1 t2
+  [ testStmtEq (ll1 `hyphen` ll2) (tEq  ll1 ll2) t1 t2
       | (ll1,t1) <- tlist , (ll2,t2) <- tlist ]
     where
-    tLab ll1 ll2 = ll1 ++ "-" ++ ll2
     tEq  ll1 ll2 = (ll1 == ll2)        ||
             (ll1,ll2) `elem` stmteqlist ||
             (ll2,ll1) `elem` stmteqlist
@@ -965,10 +972,9 @@ grapheqlist =
 
 testGraphEqSuite :: Test
 testGraphEqSuite = TestList
-  [ testGraphEq (tLab ll1 ll2) (tEq ll1 ll2) gg1 gg2
+  [ testGraphEq (ll1 `hyphen` ll2) (tEq ll1 ll2) gg1 gg2
       | (ll1,gg1) <- glist , (ll2,gg2) <- glist ]
     where
-    tLab ll1 ll2 = ll1 ++ "-" ++ ll2
     tEq  ll1 ll2 = (ll1 == ll2)        ||
             (ll1,ll2) `elem` grapheqlist ||
             (ll2,ll1) `elem` grapheqlist
@@ -1596,7 +1602,7 @@ main = TF.defaultMain allTests
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke  
+--    2011, 2012, 2013, 2014 Douglas Burke  
 --  All rights reserved.
 --
 --  This file is part of Swish.
